using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using AmazonWrapper.Amazon.ECSWebservice;

public partial class Default2 : System.Web.UI.Page
{
	private DataTable searchResult = new DataTable();
	private string subscriptionId = ConfigurationManager.AppSettings["Amazon.Webservice.SubscriptionId"].ToString();
	private string associateId = ConfigurationManager.AppSettings["Amazon.Associates.ID"].ToString();
	public string searchIndex;
	public string searchKeyword;

	protected void Page_Load(object sender, EventArgs e)
	{
		try
		{
			searchIndex = Request.QueryString["searchindex"];
			searchKeyword = Request.QueryString["searchquery"];
			if (searchIndex == string.Empty || searchKeyword == string.Empty)
			{
				lblSearchInfo.Text = "You did not enter any keywords. Please enter a keyword and try again";
			}
			else
			{
				Page.Title = "DNK Amazon Associates Webstore :: Searching for " + searchKeyword;
				if (!Page.IsPostBack)
				{
					dgrdSearchResult.CurrentPageIndex = 0;
				}
				BindSearchResult(int.Parse(searchIndex), searchKeyword);
			}
		}
		catch
		{
			lblErrMsg.Text = "An error ocurred while processing your request. Please try again later.";
		}
	}

	public void BindSearchResult(int searchIndex, string searchKeyword)
	{
		searchResult.Columns.Add(new DataColumn("Title", typeof(string)));
		searchResult.Columns.Add(new DataColumn("ASIN", typeof(string)));
		searchResult.Columns.Add(new DataColumn("ReleaseDate", typeof(string)));
		searchResult.Columns.Add(new DataColumn("Availability", typeof(string)));
		searchResult.Columns.Add(new DataColumn("ListPrice", typeof(string)));
		searchResult.Columns.Add(new DataColumn("SmallImage", typeof(string)));
		searchResult.Columns.Add(new DataColumn("AmazonPrice", typeof(string)));
		searchResult.Columns.Add(new DataColumn("Savings", typeof(string)));
		searchResult.Columns.Add(new DataColumn("DetailPageURL", typeof(string)));
		SearchIndex _searchIndex = (SearchIndex)searchIndex;
		Search(searchKeyword, "1", _searchIndex);
	}

	private void Search(string query, string pageNumber, SearchIndex searchIndex)
	{
		SearchRequest req = new SearchRequest();

		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;

		req.Keywords = query;
		req.ItemPage = pageNumber;
		req.SearchIndex = searchIndex;

		Items items = req.Search(true);

		if (items != null)
		{
			double _savings;
			double _listPrice;
			double _salesPrice;
			dgrdSearchResult.VirtualItemCount = Convert.ToInt32(items.TotalResults);
			lblSearchInfo.Text = items.TotalResults.ToString() + " items found for " + searchKeyword + " (Displaying: page " + pageNumber + " of " + items.TotalPages.ToString() + " )";


			Item[] itemArray = items.Item;
			if (itemArray != null)
			{
				searchResult.Rows.Clear();

				foreach (Item item in itemArray)
				{
					DataRow row = searchResult.NewRow();

					if (item.Offers != null)
					{
						Offer[] offerArray = item.Offers.Offer;
						if (offerArray != null)
						{
							if (offerArray[0].OfferListing != null)
							{
								if (offerArray[0].OfferListing[0].Price != null)
									row["AmazonPrice"] = offerArray[0].OfferListing[0].Price.FormattedPrice;
								if (offerArray[0].OfferListing[0].Availability != null)
									row["Availability"] = offerArray[0].OfferListing[0].Availability;
							}
						}
					}

					if (item.ItemAttributes.ListPrice != null)
						row["ListPrice"] = item.ItemAttributes.ListPrice.FormattedPrice;

					if (row["AmazonPrice"].ToString() != string.Empty)
					{
						if (row["AmazonPrice"].ToString() == "Too low to display")
							row["AmazonPrice"] = "Price available at checkout";

						try
						{
							_listPrice = double.Parse(item.ItemAttributes.ListPrice.FormattedPrice.Replace("$", "").Trim());
							_salesPrice = double.Parse(row["AmazonPrice"].ToString().Replace("$", "").Trim());
							_savings = ((_listPrice - _salesPrice) / (_listPrice) * 100);
							row["Savings"] = _savings.ToString("##.##") + "%";
						}
						catch
						{
							row["Savings"] = "N/A";
						}

						if (item.ItemAttributes.Title != null)
							row["Title"] = item.ItemAttributes.Title;

						if (item.ASIN != null)
							row["ASIN"] = item.ASIN;

						if (item.ItemAttributes.ReleaseDate != null)
							row["ReleaseDate"] = item.ItemAttributes.ReleaseDate;

						if (item.SmallImage != null)
							row["SmallImage"] = item.SmallImage.URL;
						else
							row["SmallImage"] = "noimage.gif";

						if (item.DetailPageURL != null)
							row["DetailPageURL"] = "ProductDetails.aspx?asin=" + item.ASIN;
						//row["DetailPageURL"] = item.DetailPageURL;

						searchResult.Rows.Add(row);
						DataView dv = new DataView(searchResult);
						dgrdSearchResult.DataSource = dv;
						dgrdSearchResult.DataBind();

					}

					if (searchResult.Rows.Count < 1)
					{
						lblSearchInfo.Text = "There are no products available in this category";
					}
					else
					{
						lblSearchInfo.Text = items.TotalResults.ToString() + " items found in " + searchKeyword + " (Displaying: page " + pageNumber + " of " + items.TotalPages.ToString() + " )";
					}
				}
			}
		}
	}
	public void dgrdSearchResult_PageIndexChanged(object source, System.Web.UI.WebControls.DataGridPageChangedEventArgs e)
	{
		dgrdSearchResult.CurrentPageIndex = e.NewPageIndex;
		SearchIndex index = (SearchIndex)(SearchIndex.Blended);
		Search(searchKeyword, (e.NewPageIndex + 1).ToString(), index);
	}
}
